@@ -13,16 +13,14 @@ CalendarApplet::CalendarApplet(QObject *parent, const KPluginMetaData &data, con
 {
 }
 
-CalendarApplet::~CalendarApplet()
-{
-}
+CalendarApplet::~CalendarApplet() = default;
 
 int CalendarApplet::weekNumber(const QDateTime &dateTime) const
 {
     return dateTime.date().weekNumber();
 }
 
-K_PLUGIN_CLASS(CalendarApplet)
+K_PLUGIN_CLASS_WITH_JSON(CalendarApplet, "metadata.json")
 
 #include "calendarapplet.moc"
 
